==> OSCA.intro_1.6.0.tar.gz: OSCA.intro/inst/doc/book/index.md <==
--- 
title: "Introduction to Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.16-bioc/R/library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.intro"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut, cre], Stephanie Hicks [aut], Raphael Gottardo [aut]<br/>
  **Version:** 1.6.0<br/>
  **Modified:** 2022-10-23<br/>
  **Compiled:** 2022-11-02<br/>
  **Environment:** R version 4.2.1 (2022-06-23), Bioconductor 3.16<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2022<br/>
  **Source:** https://github.com/OSCA-source/OSCA.intro"
url: "https://github.com/OSCA-source/OSCA.intro"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the introductory chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.16/OSCA).
    This describes how to install R and [Bioconductor](https://bioconductor.org) packages, links out to some resources to learn R,
    describes how to load datasets into an R session, provides an overview of the `SingleCellExperiment` class,
    and performs a "quick start" demonstration for basic single-cell RNA-seq analyses. It is intended for
    readers with little-to-no computational background who are just getting started with analyses in R.

==> OSCA.intro_1.8.0.tar.gz: OSCA.intro/inst/doc/book/index.md <==
--- 
title: "Introduction to Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.17-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.intro"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Ludwig Geistlinger [cre]<br/>
  **Version:** 1.8.0<br/>
  **Modified:** 2022-11-15<br/>
  **Compiled:** 2023-04-26<br/>
  **Environment:** R version 4.3.0 RC (2023-04-13 r84269), Bioconductor 3.17<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2023<br/>
  **Source:** https://github.com/OSCA-source/OSCA.intro"
url: "https://github.com/OSCA-source/OSCA.intro"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the introductory chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.17/OSCA).
    This describes how to install R and [Bioconductor](https://bioconductor.org) packages, links out to some resources to learn R,
    describes how to load datasets into an R session, provides an overview of the `SingleCellExperiment` class,
    and performs a "quick start" demonstration for basic single-cell RNA-seq analyses. It is intended for
    readers with little-to-no computational background who are just getting started with analyses in R.
